"use strict";
/*
 * MIT License
 *
 * Copyright (c) 2018 Choko (choko@curioswitch.org)
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
}
Object.defineProperty(exports, "__esModule", { value: true });
const brotli_webpack_plugin_1 = __importDefault(require("brotli-webpack-plugin"));
const html_webpack_plugin_1 = __importDefault(require("html-webpack-plugin"));
const webapp_webpack_plugin_1 = __importDefault(require("webapp-webpack-plugin"));
const zopfli_webpack_plugin_1 = __importDefault(require("zopfli-webpack-plugin"));
const base_1 = __importDefault(require("./base"));
const plugins = [
    new html_webpack_plugin_1.default({
        template: 'src/index.html',
        minify: {
            removeComments: true,
            collapseWhitespace: true,
            removeRedundantAttributes: true,
            useShortDoctype: true,
            removeEmptyAttributes: true,
            removeStyleLinkTypeAttributes: true,
            keepClosingSlash: true,
            minifyJS: true,
            minifyCSS: true,
            minifyURLs: true,
        },
        inject: true,
    }),
    new webapp_webpack_plugin_1.default({
        logo: 'favicon.png',
        prefix: 'icons-[hash]/',
        emitStats: true,
        statsFilename: 'iconstats.json',
    }),
    new zopfli_webpack_plugin_1.default({
        asset: '[path].gz[query]',
        algorithm: 'zopfli',
        test: /\.(js|css|html|svg)$/,
        threshold: 1024,
        minRatio: 0.9,
    }),
    new brotli_webpack_plugin_1.default({
        asset: '[path].br[query]',
        test: /\.(js|css|html|svg)$/,
        threshold: 1024,
        minRatio: 0.9,
    }),
];
const configuration = base_1.default({
    plugins,
    mode: 'production',
    output: {
        filename: '[name].[chunkhash].js',
        chunkFilename: '[name].[chunkhash].chunk.js',
        publicPath: '/static/',
    },
});
exports.default = configuration;
//# sourceMappingURL=prod.js.map